Virtual Keyboard Navigation Demo

# Virtual Keyboard Navigate Demo

#### Note: Navigation inside of the input/textarea is disabled while the toggle is active.
This includes the autocomplete extension navigation.

- Always active:
  - Clear - Clear content.
  - ← - Move caret left.
  - → - Move caret right.
  - Backspace - Delete character to the left.

- Toggle must be active to use:
  - Home - Move to the first key in the row.
  - Up - Move up one row.
  - Page Up - Move to the first row.
  - Left - Move one key left.
  - Shift-F1 - Toggle navigation (textarea and keyboard).
  - Right - Move one key right.
  - End - Move to the last key in the row.
  - Down - Move down one row.
  - Page Down - Move to the last row.
  - Delete (← Caret) - Move caret left.
  - Enter - Add the highlighted key.
  - Insert (Caret →) - Move caret right.